#!/bin/sh

#input parameters: 
# $1: working directory, $2: input file name, $3: output directory, $4: type (0: autodetect, 1: xml, 2: zip, 3: gz, 4: tar.gz, 5: tar.bz2)

FILENAME=$2
OUTPUTDIR=$3
FILETYPE=$4

DetectFileTypeFunc()
{
	case "$FILENAME" in 
		*.xml) 
		echo "XML file type detected"
		FILETYPE=1
		return
		;;
	esac

	case "$FILENAME" in 
		*.zip) 
		echo "ZIP file type detected"
		FILETYPE=2
		return
		;;
	esac

	case "$FILENAME" in 
		*.tar.gz) 
		echo "tar.gz file type detected"
		FILETYPE=4
		return
		;;
	esac

	case "$FILENAME" in 
		*.tar.bz2) 
		echo "tar.bz2 file type detected"
		FILETYPE=5
		return
		;;
	esac

	case "$FILENAME" in 
		*.gz) 
		echo "GZ file type detected"
		FILETYPE=3
		return
		;;
	esac

	echo "Unable to determine file type"
}

#go to working directory
cd $1

# check input file type
if [ "$FILETYPE" = "0" ];
then
	echo "Autodetecting file type for $FILENAME ..."
	DetectFileTypeFunc
fi

echo "Detected file type: $FILETYPE"

mkdir -p $OUTPUTDIR

if [ "$FILETYPE" = "1" ];
then
	# xml file
	# move file to the output dir
	mv $FILENAME $OUTPUTDIR/
fi

if [ "$FILETYPE" = "2" ];
then
	# ZIP file
	mv $FILENAME $OUTPUTDIR
	cd $OUTPUTDIR
	unzip $FILENAME
	cd ..
	mv $OUTPUTDIR/$FILENAME ./
fi

if [ "$FILETYPE" = "3" ];
then
	# GZ file
	mv $FILENAME $OUTPUTDIR
	cd $OUTPUTDIR
	gunzip -f $FILENAME
	cd ..
fi

if [ "$FILETYPE" = "4" ];
then
	# TAR.GZ file
	mv $FILENAME $OUTPUTDIR
	cd $OUTPUTDIR
	tar -xzvf $FILENAME
	cd ..
	mv $OUTPUTDIR/$FILENAME ./
fi

if [ "$FILETYPE" = "5" ];
then
	# TAR.BZ2 file
	mv $FILENAME $OUTPUTDIR
	cd $OUTPUTDIR
	tar -xjvf $FILENAME
	cd ..
	mv $OUTPUTDIR/$FILENAME ./
fi

cd $OUTPUTDIR

for f in *
do
	case "$f" in 
		*.xml) 
			#file already has .xml extension
		;;

		*) 
			echo "Adding .xml to the file name $f"
			mv $f $f.xml
		;;
	esac
done

cd ..

